Class: Google::Cloud::DocumentAI::V1::BatchProcessRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DocumentAI::V1::BatchProcessRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/documentai/v1/document_processor_service.rb
Overview
Request message for BatchProcessDocuments.
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#document_output_config ⇒ ::Google::Cloud::DocumentAI::V1::DocumentOutputConfig
The output configuration for the BatchProcessDocuments method.
-
#input_documents ⇒ ::Google::Cloud::DocumentAI::V1::BatchDocumentsInputConfig
The input documents for the BatchProcessDocuments method.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Required.
-
#process_options ⇒ ::Google::Cloud::DocumentAI::V1::ProcessOptions
Inference-time options for the process API.
-
#skip_human_review ⇒ ::Boolean
Whether human review should be skipped for this request.
Instance Attribute Details
#document_output_config ⇒ ::Google::Cloud::DocumentAI::V1::DocumentOutputConfig
Returns The output configuration for the BatchProcessDocuments method.
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'proto_docs/google/cloud/documentai/v1/document_processor_service.rb', line 265 class BatchProcessRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#input_documents ⇒ ::Google::Cloud::DocumentAI::V1::BatchDocumentsInputConfig
Returns The input documents for the BatchProcessDocuments method.
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'proto_docs/google/cloud/documentai/v1/document_processor_service.rb', line 265 class BatchProcessRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. The labels with user-defined metadata for the request.
Label keys and values can be no longer than 63 characters (Unicode codepoints) and can only contain lowercase letters, numeric characters, underscores, and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter.
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'proto_docs/google/cloud/documentai/v1/document_processor_service.rb', line 265 class BatchProcessRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Required. The resource name of
Processor or
ProcessorVersion.
Format: projects/{project}/locations/{location}/processors/{processor},
or
projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}.
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'proto_docs/google/cloud/documentai/v1/document_processor_service.rb', line 265 class BatchProcessRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#process_options ⇒ ::Google::Cloud::DocumentAI::V1::ProcessOptions
Returns Inference-time options for the process API.
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'proto_docs/google/cloud/documentai/v1/document_processor_service.rb', line 265 class BatchProcessRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#skip_human_review ⇒ ::Boolean
Returns Whether human review should be skipped for this request. Default to
false.
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'proto_docs/google/cloud/documentai/v1/document_processor_service.rb', line 265 class BatchProcessRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |