Class: Google::Cloud::DocumentAI::V1::Document::Annotations
- Inherits:
-
Object
- Object
- Google::Cloud::DocumentAI::V1::Document::Annotations
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/documentai/v1/document.rb
Overview
Represents the annotation of a block or a chunk.
Instance Attribute Summary collapse
-
#description ⇒ ::String
The description of the content with this annotation.
Instance Attribute Details
#description ⇒ ::String
Returns The description of the content with this annotation.
1125 1126 1127 1128 |
# File 'proto_docs/google/cloud/documentai/v1/document.rb', line 1125 class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |