Class: Google::Cloud::DocumentAI::V1::Document::BlobAsset
- Inherits:
-
Object
- Object
- Google::Cloud::DocumentAI::V1::Document::BlobAsset
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/documentai/v1/document.rb
Overview
Represents a blob asset. It's used to store the content of the inline blob in this document, for example, image bytes, such that it can be referenced by other fields in the document via asset ID.
Instance Attribute Summary collapse
-
#asset_id ⇒ ::String
Optional.
-
#content ⇒ ::String
Optional.
-
#mime_type ⇒ ::String
The mime type of the blob asset.
Instance Attribute Details
#asset_id ⇒ ::String
Returns Optional. The id of the blob asset.
1453 1454 1455 1456 |
# File 'proto_docs/google/cloud/documentai/v1/document.rb', line 1453 class BlobAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#content ⇒ ::String
Returns Optional. The content of the blob asset, for example, image bytes.
1453 1454 1455 1456 |
# File 'proto_docs/google/cloud/documentai/v1/document.rb', line 1453 class BlobAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mime_type ⇒ ::String
Returns The mime type of the blob asset. An IANA published media type (MIME type).
1453 1454 1455 1456 |
# File 'proto_docs/google/cloud/documentai/v1/document.rb', line 1453 class BlobAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |